%global momorel 3

%define	_root_sbindir	/sbin
%define	_root_libdir	/%{_lib}

Summary: Utilities for managing the second and third extended (ext2/ext3) filesystems
Name: e2fsprogs
Version: 1.40.2
Release: %{momorel}m%{?dist}
License: GPL
Group: System Environment/Base
Source0:  http://dl.sourceforge.net/sourceforge/e2fsprogs/e2fsprogs-%{version}.tar.gz
Source1: ext2_types-wrapper.h
Source2: blkid_types-wrapper.h
NoSource: 0

Patch30: e2fsprogs-1.38-resize-inode.patch
Patch32: e2fsprogs-1.38-no_pottcdate.patch
Patch34: e2fsprogs-1.39-blkid-devmapper.patch
Patch36: e2fsprogs-1.38-etcblkid.patch
Patch39: e2fsprogs-1.39-multilib.patch
Patch62: e2fsprogs-1.39-mkinstalldirs.patch
Patch63: e2fsprogs-1.40.2-warning-fixes.patch
Patch64: e2fsprogs-1.40.2-swapfs.patch
Patch65: e2fsprogs-1.40.2-fix-open-create-modes.patch
Patch66: e2fsprogs-1.40.2-protect-open-ops.patch
Patch67: e2fsprogs-1.40.2-blkid-FAT-magic-not-on-strict-position.patch
Patch68: e2fsprogs-1.40.2-blkid-squashfs.patch

# for security
Patch100: e2fsprogs-1.40.2-CVE-2007-5497.patch

Url: http://e2fsprogs.sourceforge.net/
BuildRoot: %{_tmppath}/%{name}-%{version}-root
Requires: e2fsprogs-libs = %{version}-%{release}, device-mapper
BuildRequires: gettext, texinfo, autoconf, automake, libselinux-devel
BuildRequires: libsepol-devel, gettext-devel, pkgconfig
BuildRequires: device-mapper >= 1.02.02-3
Obsoletes: ext2resize

%description
The e2fsprogs package contains a number of utilities for creating,
checking, modifying, and correcting any inconsistencies in second
and third extended (ext2/ext3) filesystems. E2fsprogs contains
e2fsck (used to repair filesystem inconsistencies after an unclean
shutdown), mke2fs (used to initialize a partition to contain an
empty ext2 filesystem), debugfs (used to examine the internal
structure of a filesystem, to manually repair a corrupted
filesystem, or to create test cases for e2fsck), tune2fs (used to
modify filesystem parameters), and most of the other core ext2fs
filesystem utilities.

You should install the e2fsprogs package if you need to manage the
performance of an ext2 and/or ext3 filesystem.

%package libs
Summary: Ext2 filesystem-specific static libraries and headers.
Group: Development/Libraries
#Prereq: /sbin/ldconfig
Prereq: glibc

%description libs
E2fsprogs-lib contains the libraries of the e2fsprogs package.

%package devel
Summary: Ext2/3 filesystem-specific static libraries and headers
Group: Development/Libraries
Requires: e2fsprogs-libs = %{version}-%{release}
#Prereq: /sbin/install-info
Prereq: info

%description devel
E2fsprogs-devel contains the libraries and header files needed to
develop second and third extended (ext2/ext3) filesystem-specific
programs.

You should install e2fsprogs-devel if you want to develop ext2/ext3
filesystem-specific programs. If you install e2fsprogs-devel, you'll
also want to install e2fsprogs.
#'

%prep
%setup -q -n e2fsprogs-%{version}
# enable tune2fs to set and clear the resize inode (#167816)
%patch30 -p1 -b .resize-inode
# drop timestamp from mo files (#168815/168814/245653)
%patch32 -p1 -b .pottcdate
# look at device mapper devices
%patch34 -p1 -b .dm
# put blkid.tab in /etc/blkid/
%patch36 -p1 -b .etcblkid
# Fix multilib conflicts (#192665)
%patch39 -p1 -b .multilib
# Fix for newer autoconf (#220715)
%patch62 -p1 -b .mkinstalldirs
# Fix type warning in badblocks
%patch63 -p1 -b .warnings
# Fix ext2fs_swap_inode_full() on bigendian boxes
%patch64 -p1 -b .swapfs
# fix one open("foo", O_CREAT) caller with no mode
%patch65 -p1 -b .creatmode
# protect ->open ops from glibc open-create-mode-checker
%patch66 -p1 -b .open
# fix fat probe when there is a real MBR
%patch67 -p1 -b .blkid-fat
# detect squashfs in libblkid (#305151)
%patch68 -p1 -b .blkid-squashfs
# fix security issue (CVE-2007-5497)
%patch100 -p1 -b .CVE-2007-5497

%build
aclocal
autoconf
%configure --enable-elf-shlibs --enable-nls --disable-e2initrd-helper  --enable-blkid-devmapper --enable-blkid-selinux
make -C po update-po
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
export PATH=/sbin:$PATH
make install install-libs DESTDIR=%{buildroot} INSTALL="%{__install} -p" \
	root_sbindir=%{_root_sbindir} root_libdir=%{_root_libdir}

# ugly hack to allow parallel install of 32-bit and 64-bit -devel packages:
mv -f %{buildroot}%{_includedir}/ext2fs/ext2_types.h \
      %{buildroot}%{_includedir}/ext2fs/ext2_types-%{_arch}.h
install -p -m 644 %{SOURCE1} %{buildroot}%{_includedir}/ext2fs/ext2_types.h

mv -f %{buildroot}%{_includedir}/blkid/blkid_types.h \
      %{buildroot}%{_includedir}/blkid/blkid_types-%{_arch}.h
install -p -m 644 %{SOURCE2} %{buildroot}%{_includedir}/blkid/blkid_types.h

# It fails when arch is i686. 
sed -i 's/blkid_types-i386.h/blkid_types-i686.h/g' %{buildroot}%{_includedir}/blkid/blkid_types.h
sed -i 's/ext2_types-i386.h/ext2_types-i686.h/g' %{buildroot}%{_includedir}/ext2fs/ext2_types.h

%find_lang %{name}

%check
make check

%clean
rm -rf %{buildroot}

%post
[ -e /etc/blkid.tab ] && mv /etc/blkid.tab /etc/blkid/blkid.tab || :
[ -e /etc/blkid.tab.old ] && mv /etc/blkid.tab.old /etc/blkid/blkid.tab.old || :

%post libs -p /sbin/ldconfig

%postun libs -p /sbin/ldconfig

%post devel
if [ -x /sbin/install-info ]; then
    /sbin/install-info %{_infodir}/libext2fs.info.* %{_infodir}/dir
fi
exit 0

%postun devel
if [ $1 = 0 ]; then
   /sbin/install-info --delete %{_infodir}/libext2fs.info.* %{_infodir}/dir
fi
exit 0

%files -f %{name}.lang
%defattr(-,root,root)
%doc README RELEASE-NOTES

%dir /etc/blkid
%config(noreplace) /etc/mke2fs.conf
%{_root_sbindir}/badblocks
%{_root_sbindir}/blkid
%{_root_sbindir}/debugfs
%{_root_sbindir}/dumpe2fs
%{_root_sbindir}/e2fsck
%{_root_sbindir}/e2image
%{_root_sbindir}/e2label
%{_root_sbindir}/findfs
%{_root_sbindir}/fsck
%{_root_sbindir}/fsck.ext2
%{_root_sbindir}/fsck.ext3
%{_root_sbindir}/logsave
%{_root_sbindir}/mke2fs
%{_root_sbindir}/mkfs.ext2
%{_root_sbindir}/mkfs.ext3
%{_root_sbindir}/resize2fs
%{_root_sbindir}/tune2fs
%{_sbindir}/filefrag
%{_sbindir}/mklost+found

%{_bindir}/chattr
%{_bindir}/lsattr
%{_bindir}/uuidgen
%{_mandir}/man1/chattr.1*
%{_mandir}/man1/lsattr.1*
%{_mandir}/man1/uuidgen.1*

%{_mandir}/man5/e2fsck.conf.5*
%{_mandir}/man5/mke2fs.conf.5*

%{_mandir}/man8/badblocks.8*
%{_mandir}/man8/blkid.8*
%{_mandir}/man8/debugfs.8*
%{_mandir}/man8/dumpe2fs.8*
%{_mandir}/man8/e2fsck.8*
%{_mandir}/man8/findfs.8*
%{_mandir}/man8/filefrag.8*
%{_mandir}/man8/fsck.ext2.8*
%{_mandir}/man8/fsck.ext3.8*
%{_mandir}/man8/e2image.8*
%{_mandir}/man8/e2label.8*
%{_mandir}/man8/fsck.8*
%{_mandir}/man8/logsave.8*
%{_mandir}/man8/mke2fs.8*
%{_mandir}/man8/mkfs.ext2.8*
%{_mandir}/man8/mkfs.ext3.8*
%{_mandir}/man8/mklost+found.8*
%{_mandir}/man8/resize2fs.8*
%{_mandir}/man8/tune2fs.8*

%files libs
%defattr(-,root,root)
%{_root_libdir}/libblkid.so.*
%{_root_libdir}/libcom_err.so.*
%{_root_libdir}/libe2p.so.*
%{_root_libdir}/libext2fs.so.*
%{_root_libdir}/libss.so.*
%{_root_libdir}/libuuid.so.*

%files devel
%defattr(-,root,root)
%{_infodir}/libext2fs.info*
%{_bindir}/compile_et
%{_bindir}/mk_cmds

%{_libdir}/libblkid.a
%{_libdir}/libblkid.so
%{_libdir}/libcom_err.a
%{_libdir}/libcom_err.so
%{_libdir}/libe2p.a
%{_libdir}/libe2p.so
%{_libdir}/libext2fs.a
%{_libdir}/libext2fs.so
%{_libdir}/libss.a
%{_libdir}/libss.so
%{_libdir}/libuuid.a
%{_libdir}/libuuid.so
%{_libdir}/pkgconfig/*.pc

%{_datadir}/et
%{_datadir}/ss
%{_includedir}/blkid
%{_includedir}/e2p
%{_includedir}/et
%{_includedir}/ext2fs
%{_includedir}/ss
%{_includedir}/uuid
%{_mandir}/man1/compile_et.1*
%{_mandir}/man1/mk_cmds.1*
%{_mandir}/man3/com_err.3*
%{_mandir}/man3/libblkid.3*
%{_mandir}/man3/uuid.3*
%{_mandir}/man3/uuid_clear.3*
%{_mandir}/man3/uuid_compare.3*
%{_mandir}/man3/uuid_copy.3*
%{_mandir}/man3/uuid_generate.3*
%{_mandir}/man3/uuid_generate_random.3*
%{_mandir}/man3/uuid_generate_time.3*
%{_mandir}/man3/uuid_is_null.3*
%{_mandir}/man3/uuid_parse.3*
%{_mandir}/man3/uuid_time.3*
%{_mandir}/man3/uuid_unparse.3*

%changelog
* Fri Dec 28 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (1.40.2-3m)
- fails when arch is i686

* Mon Dec 24 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (1.40.2-2m)
- fails when arch is i686

* Mon Dec 10 2007 NARITA Koichi <pulsar@momonga-linux.org>
- (1.40.2-1m)
- [SECURITY] CVE-2007-5497
- update to 1.40.2 and almost sync with Fedora devel
- clean up repository

* Mon Nov 20 2006 TABUCHI Takaaki <tab@momonga-linux.org>
- (1.39-3m)
- - sync with 1.39-7 from fc-devel
- - rename patch40 to patch140
- - add patch40 .. patch60
- - add Obsoletes: ext2resize
- - changelog is below
-* Wed Sep 20 2006 Jarod Wilson <jwilson@redhat.com> - 1.39-7
-- 32-bit 16T fixups from esandeen (#202807)
-- Update summaries and descriptions
-
-* Sun Sep 17 2006 Karel Zak <kzak@redhat.com> - 1.39-6
-- Fix problem with empty FAT label (#206656)
-
-* Tue Sep  5 2006 Peter Jones <pjones@redhat.com> - 1.39-5
-- Fix memory leak in device probing.

* Mon Oct  9 2006 Nishio Futoshi <futoshi@momonga-linux.org>
- (1.39-2m)
- add patch40 (for mkinstalldirs)

* Sun Jul 30 2006 TABUCHI Takaaki <tab@momonga-linux.org>
- (1.39-1m)
- update to 1.39
  - sync with 1.39-4 from fc-devel

* Sun May 14 2006 Masahiro Takahata <takahata@momonga-linux.org>
- (1.38-2m)
- modify for 64 bit arch

* Sun May  7 2006 TABUCHI Takaaki <tab@momonga-linux.org>
- (1.38-1m)
- version up based on Fedora (1.38-12)
-  Wed Mar  8 2006 Peter Jones <pjones@redhat.com> - 1.38-12
- - Move /etc/blkid.tab to /etc/blkid/blkid.tab
- 
- * Tue Mar  7 2006 David Cantrell <dcantrell@redhat.com> - 1.38-11
- - BuildRequires pkgconfig
- 
- * Tue Mar  7 2006 David Cantrell <dcantrell@redhat.com> - 1.38-10
- - Disable /etc/blkid.tab caching if time is set before epoch (#182188)
- 
- * Fri Feb 24 2006 Peter Jones <pjones@redhat.com> - 1.38-9
- - _don't_ handle selinux context on blkid.tab, dwalsh says this is a no-no.
- #'
- * Wed Feb 22 2006 Peter Jones <pjones@redhat.com> - 1.38-8
- - handle selinux context on blkid.tab
- 
- * Mon Feb 20 2006 Karsten Hopp <karsten@redhat.de> 1.38-7
- - BuildRequires: gettext-devel
- 
- * Fri Feb 10 2006 Jesse Keating <jkeating@redhat.com> - 1.38-6.2
- - bump again for double-long bug on ppc(64)
- 
- * Tue Feb  7 2006 Jesse Keating <jkeating@redhat.com> - 1.38-6.1
- - rebuilt for new gcc4.1 snapshot and glibc changes
- 
- * Wed Jan 11 2006 Karel Zak <kzak@redhat.com> 1.38-6
- - cleanup device-mapper patch
- - use pkg-config for device-mapper
- 
- * Mon Jan  9 2006 Peter Jones <pjones@redhat.com> 1.38-5
- - fix some more minor logic errors in dm probing
- 
- * Wed Jan  4 2006 Peter Jones <pjones@redhat.com> 1.38-4
- - fix a logic error in dm probing
- - add priority group for dm devices, so they'll be preferred
- #'
- * Tue Jan  3 2006 Peter Jones <pjones@redhat.com> 1.38-3
- - added support for device-mapper devices
- 
- * Fri Dec  9 2005 Jesse Keating <jkeating@redhat.com>
- - rebuilt
- 
- * Thu Nov 10 2005 Thomas Woerner <twoerner@redhat.com> 1.38-2.1
- - fixed file conflicts between 32bit and 64bit packages (#168815)
- - fixed mklost+found crashes with buffer overflow (#157773)
-   Thanks to Arjan van de Ven for the patch
- 
- * Wed Nov  9 2005 Thomas Woerner <twoerner@redhat.com> 1.38-2
- - splitted up libs from main package, into a new e2fsprogs-libs package
- - fixed requires and prereqs
- 
- * Thu Sep  8 2005 Thomas Woerner <twoerner@redhat.com> 1.38-1
- - new version 1.38
- - Close File descriptor for unregognized devices (#159878)
-   Thanks to David Milburn for the patch.
-   Merged from RHEL-4
- - enable tune2fs to set and clear feature resize_inode (#167816)
- - removed outdated information from ext2online man page (#164383)

* Wed Jan  4 2006 YAMAZAKI Makoto <zaki@zakky.org>
- (1.37-2m)
- set svn:eol-style property to
   e2fsprogs-1.1589.patch
   e2fsprogs-1.1590.patch
   e2fsprogs-1.1591.patch

* Sun May 22 2005 Hiroyuki Koga <kuma@momonga-linux.org>
- (1.37-1m)
- version up based on Fedora (1.37-4)

  * Tue May 10 2005 Jeremy Katz <katzj@redhat.com> - 1.37-4
  - added libblkid.so to devel package

  * Wed May  4 2005 Jeremy Katz <katzj@redhat.com> - 1.37-3
  - fix cramfs detection bug in libblkid

  * Fri Apr  8 2005 Thomas Woerner <twoerner@redhat.com> 1.37-2
  - upstream fixes 1.1589, 1.1590 and 1.1591:
  - add include of stdlib.h to fix a core dump bug on IA64
  - ignore environment variables in blkid and ext2fs for setuid and setguid
    programs
  - no LOW_DTIME checks if the superblock last mount time looks insane

  * Fri Apr  8 2005 Thomas Woerner <twoerner@redhat.com> 1.37-1
  - new version 1.37
  - dropped upstream merged getsize-wrap patch

  * Wed Mar 16 2005 Stephen C. Tweedie <sct@redhat.com> 1.36-1.4
  - Fix the getsize-wrap patch for >4TB filesystems

  * Mon Feb 21 2005 Stephen C. Tweedie <sct@redhat.com> 1.36-1.2
  - Re-enable resize2fs
  - Add bigendian byte-swapping fix when growing the gdt table

  * Fri Feb 11 2005 Stephen C. Tweedie <sct@redhat.com> 1.36-1.1
  - Fix for >=4TB devices

* Tue Jan 25 2005 TABUCHI Takaaki <tab@momonga-linux.org>
- (1.35-2m)
- merge FC3 (1.35-11.2)

* Thu Sep 30 2004 YAMAZAKI Makoto <zaki@zakky.org>
- (1.35-2m)
- use %%{_lib} instead of lib

* Wed Mar 17 2004 YAMAZAKI Makoto <zaki@zakky.org>
- (1.35-1m)
- update to 1.35

* Wed Mar 17 2004 Toru Hoshina <t@momonga-linux.org>
- (1.34-2m)
- revised spec for enabling rpm 4.2.

* Mon Aug 25 2003 Masahiro Takahata <takahata@momonga-linux.org>
- (1.34-1m)
- update to 1.34

* Mon Mar 17 2003 KOMATSU Shinichiro <koma2@momonga-linux.org>
- (1.32-1m)
- update to 1.32
- unapply e2fsprogs-1.19-mountlabel3.patch
  (I am not sure whether it is still needed). 
- use * and macros in %%files section
- add more documents

* Wed Oct 30 2002 KOMATSU Shinichiro <koma2@jiro.c.u-tokyo.ac.jp>
- (1.29-1m)
- update to 1.29
- s/telia/us/

* Tue Apr 30 2002 Kenta MURATA <muraken@kondara.org>
- (1.27-6k)
- omit /sbin/ldconfig in PreReq.
- /sbin/install-info -> info in PreReq.

* Mon Apr  8 2002 Toru Hoshina <t@@kondara.org>
- (1.27-4k)
- a couple of commands lost.

* Wed Mar 20 2002 Tsutomu Yasuda <tom@kondara.org>
- (1.27-2k)
- update to 1.27

* Fri May  4 2001 YAMAGUCHI Kenji <yamk@kondara.org>
- (1.19-8k)
- merged RedHat esfsprogs-1.19-4.src.rpm patches for mountlabel.
- append URL:
- %{_tmppath}

* Wed Oct 25 2000 MATSUDA, Daiki <dyky@df-usa.com>
- modifiled %post and %preun section from .gz to .bz2

* Tue Aug 30 2000 Kazuhiko <kazuhiko@kondara.org>
- version 1.19
- remove e2fsprogs-debugfsy2k.patch
- add fsck.ext3, resize2fs, resize2fs.8*

* Sat Jul  8 2000 Toru Hoshina <t@kondara.org>
- rebuild against glibc-2.1.90, X-4.0, rpm-3.0.5.

* Sat Jun  3 2000 MATSUDA, Daiki <dyky@df-usa.com>
- uncheck fsck.reiserfs

* Sun Apr 02 2000 Takaaki Tabuchi <tab@kondara.org>
- merge redhat6.2(Release 5)
- add patch, Prereq, post devel , postun devel.

* Wed Mar 1 2000 Masako Hattori <maru@kondara.org>
- change jman mv->cp

* Wed Feb 23 2000 Masako Hattori <maru@kondara.org>
- do not shake %{_mandir}/ja

* Sat Feb  5 2000 Bill Nottingham <notting@redhat.com>
- add install-info scripts

* Thu Feb 03 2000 Elliot Lee <sopwith@redhat.com>
- Fix bug #8585 (Y2K problems in debugfs)

* Wed Feb 02 2000 Jakub Jelinek <jakub@redhat.com>
- allow multiline errors in et, so that other programs
  can use compile_et (from Kerberos)

* Tue Feb 1 2000 Masako Hattori <maru@kondara.org>
- add man-pages-ja-e2fsprogs-20000115

* Thu Jan 13 2000 Jeff Johnson <jbj@redhat.com>
- build 1.18 for 6.2.

* Sun Nov 28 1999 Masako Hattori <maru@kondara.org>
- add man-pages-ja-e2fsprogs-19991115

* Thu Nov 18 1999 Norihito Ohmori <nono@kondara.org>
- be a NoSrc :-P

* Tue Oct 26 1999 Bill Nottingham <notting@redhat.com>
- update to 1.17

* Mon Oct 25 1999 Bill Nottingham <notting@redhat.com>
- update to 1.16

* Thu Oct 21 1999 Bill Nottingham <notting@redhat.com>
- add patch to fix SIGUSR1 kills.

* Mon Oct 04 1999 Cristian Gafton <gafton@redhat.com>
- rebuild against new glibc in the sparc tree

* Thu Sep 23 1999 Jakub Jelinek <jakub@redhat.com>
- update mke2fs man page so that it reflects changes in mke2fs
  netweem 1.14 and 1.15

* Thu Aug  5 1999 Bill Nottingham <notting@redhat.com>
- fix lsattr on alpha

* Thu Jul 29 1999 Jeff Johnson <jbj@redhat.com>
- update to 1.15.

* Sun Mar 21 1999 Cristian Gafton <gafton@redhat.com> 
- auto rebuild in the new build environment (release 4)

* Tue Mar 16 1999 Cristian Gafton <gafton@redhat.com>
- fix fsck segfault

* Tue Feb  2 1999 Jeff Johnson <jbj@redhat.com>
- update to 1.14
- use %configure to generate config.sub on arm

* Thu Jan 14 1999 Jeff Johnson <jbj@redhat.com>
- fix /usr/bin/compile_et and doco for com_err.h (#673)

* Thu Jan 07 1999 Cristian Gafton <gafton@redhat.com>
- build with prefix=/usr
- add arm patch

* Mon Dec 28 1998 Jeff Johnson  <jbj@redhat.com>
- update to 1.13.

* Fri Aug 28 1998 Jeff Johnson <jbj@redhat.com>
- recompile statically linked binary for 5.2/sparc

* Mon Jul 13 1998 Jeff Johnson <jbj@redhat.com>
- upgrade to 1.12.

* Thu May 07 1998 Prospector System <bugs@redhat.com>
- translations modified for de, fr, tr

* Thu Apr 30 1998 Cristian Gafton <gafton@redhat.com>
- include <asm/types.h> to match kernel types in utils

* Tue Oct 14 1997 Donnie Barnes <djb@redhat.com>
- spec file cleanups

* Wed Oct 01 1997 Erik Troan <ewt@redhat.com>
- fixed broken llseek() prototype 

* Wed Aug 20 1997 Erik Troan <ewt@redhat.com>
- added patch to prototype llseek

* Tue Jun 17 1997 Erik Troan <ewt@redhat.com>
- built against glibc
